.. visaplan.plone.tools documentation master file, created by
   sphinx-quickstart on Wed Jun 13 11:31:08 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

====================
visaplan.plone.tools
====================

Miscellaneous Python tools for Plone (or Zope) extensions.

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
